@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: haskell-src-exts
 version: 1.17.1
-id: haskell-src-exts-1.17.1-7afd8d2f109e171c19a1cb4891217e0d
-key: haske_JDUB8hqF1uTJd7lozF5HU4
+id: haskell-src-exts-1.17.1-3d12ae784d636e2d6ddab796cfe281a8
+key: haske_Eu34xi0wSj7HRVt5RLTtuk
 license: BSD3
 maintainer: Niklas Broberg <niklas.broberg@chalmers.se>, Roman Cheplyaka <roma@ro-che.info>
 stability: Stable
@@ -56,11 +56,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/haskell-src-exts-1.17.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/haskell-src-exts-1.17.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/haskell-src-exts-1.17.1
-hs-libraries: HShaskell-src-exts-1.17.1-JDUB8hqF1uTJd7lozF5HU4
+hs-libraries: HShaskell-src-exts-1.17.1-Eu34xi0wSj7HRVt5RLTtuk
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    cpphs-1.19.3-8cb6c3761dbbd3c20e10f28974c8d246
+    cpphs-1.20.1-46b13f1ef390a545ec653266d5170426
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
     pretty-1.1.2.0-b06321e1e395640194b358a5374c465f
 haddock-interfaces: /usr/share/doc/haskell-src-exts/html/haskell-src-exts.haddock
